==> pcep-topology-api-0.21.7-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/topology/pcep/rev220730/pcep/client/attributes/PathComputationClientBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes;
import java.lang.Class;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddressNoZone;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.PccSyncState;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.ReportedLsp;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.ReportedLspKey;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.StatefulTlv;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;

/**
 * Class that builds {@link PathComputationClient} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     PathComputationClient createPathComputationClient(int fooXyzzy, int barBaz) {
 *         return new PathComputationClientBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of PathComputationClient, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see PathComputationClient
 *
 */
@Generated("mdsal-binding-generator")
public class PathComputationClientBuilder {

    private IpAddressNoZone _ipAddress;
    private Map<ReportedLspKey, ReportedLsp> _reportedLsp;
    private PccSyncState _stateSync;
    private StatefulTlv _statefulTlv;


    Map<Class<? extends Augmentation<PathComputationClient>>, Augmentation<PathComputationClient>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public PathComputationClientBuilder() {
        // No-op
    }

    

    /**
     * Construct a builder initialized with state from specified {@link PathComputationClient}.
     *
     * @param base PathComputationClient from which the builder should be initialized
     */
    public PathComputationClientBuilder(PathComputationClient base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._ipAddress = base.getIpAddress();
        this._reportedLsp = base.getReportedLsp();
        this._stateSync = base.getStateSync();
        this._statefulTlv = base.getStatefulTlv();
    }


    private static final class LazyEmpty {
        static final @NonNull PathComputationClient INSTANCE = new PathComputationClientBuilder().build();
    
        private LazyEmpty() {
            // Hidden on purpose
        }
    }
    
    /**
     * Get empty instance of PathComputationClient.
     *
     * @return An empty {@link PathComputationClient}
     */
    public static @NonNull PathComputationClient empty() {
        return LazyEmpty.INSTANCE;
    }

    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getIpAddress()}.
     *
     * @return current value
     */
    public IpAddressNoZone getIpAddress() {
        return _ipAddress;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getReportedLsp()}.
     *
     * @return current value
     */
    public Map<ReportedLspKey, ReportedLsp> getReportedLsp() {
        return _reportedLsp;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getStateSync()}.
     *
     * @return current value
     */
    public PccSyncState getStateSync() {
        return _stateSync;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getStatefulTlv()}.
     *
     * @return current value
     */
    public StatefulTlv getStatefulTlv() {
        return _statefulTlv;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<PathComputationClient>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    /**
     * Set the property corresponding to {@link PathComputationClient#getIpAddress()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PathComputationClientBuilder setIpAddress(final IpAddressNoZone value) {
        this._ipAddress = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link PathComputationClient#getReportedLsp()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public PathComputationClientBuilder setReportedLsp(final Map<ReportedLspKey, ReportedLsp> values) {
        this._reportedLsp = values;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link PathComputationClient#getStateSync()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PathComputationClientBuilder setStateSync(final PccSyncState value) {
        this._stateSync = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link PathComputationClient#getStatefulTlv()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PathComputationClientBuilder setStatefulTlv(final StatefulTlv value) {
        this._statefulTlv = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public PathComputationClientBuilder addAugmentation(Augmentation<PathComputationClient> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public PathComputationClientBuilder removeAugmentation(Class<? extends Augmentation<PathComputationClient>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link PathComputationClient} instance.
     *
     * @return A new {@link PathComputationClient} instance.
     */
    public @NonNull PathComputationClient build() {
        return new PathComputationClientImpl(this);
    }

    private static final class PathComputationClientImpl
        extends AbstractAugmentable<PathComputationClient>
        implements PathComputationClient {
    
        private final IpAddressNoZone _ipAddress;
        private final Map<ReportedLspKey, ReportedLsp> _reportedLsp;
        private final PccSyncState _stateSync;
        private final StatefulTlv _statefulTlv;
    
        PathComputationClientImpl(PathComputationClientBuilder base) {
            super(base.augmentation);
            this._ipAddress = base.getIpAddress();
            this._reportedLsp = CodeHelpers.emptyToNull(base.getReportedLsp());
            this._stateSync = base.getStateSync();
            this._statefulTlv = base.getStatefulTlv();
        }
    
        @Override
        public IpAddressNoZone getIpAddress() {
            return _ipAddress;
        }
        
        @Override
        public Map<ReportedLspKey, ReportedLsp> getReportedLsp() {
            return _reportedLsp;
        }
        
        @Override
        public PccSyncState getStateSync() {
            return _stateSync;
        }
        
        @Override
        public StatefulTlv getStatefulTlv() {
            return _statefulTlv;
        }
    
        
        
        
        @Override
        public StatefulTlv nonnullStatefulTlv() {
            return Objects.requireNonNullElse(getStatefulTlv(), org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.StatefulTlvBuilder.empty());
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = PathComputationClient.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return PathComputationClient.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return PathComputationClient.bindingToString(this);
        }
    }
}

==> pcep-topology-api-0.22.4-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/topology/pcep/rev220730/pcep/client/attributes/PathComputationClientBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes;
import java.lang.Class;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddressNoZone;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.PccSyncState;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.ReportedLsp;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.ReportedLspKey;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.StatefulTlv;
import org.opendaylight.yangtools.binding.Augmentation;
import org.opendaylight.yangtools.binding.lib.AbstractAugmentable;
import org.opendaylight.yangtools.binding.lib.CodeHelpers;

/**
 * Class that builds {@link PathComputationClient} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     PathComputationClient createPathComputationClient(int fooXyzzy, int barBaz) {
 *         return new PathComputationClientBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of PathComputationClient, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see PathComputationClient
 *
 */
@Generated("mdsal-binding-generator")
public class PathComputationClientBuilder {

    private IpAddressNoZone _ipAddress;
    private Map<ReportedLspKey, ReportedLsp> _reportedLsp;
    private PccSyncState _stateSync;
    private StatefulTlv _statefulTlv;


    Map<Class<? extends Augmentation<PathComputationClient>>, Augmentation<PathComputationClient>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public PathComputationClientBuilder() {
        // No-op
    }

    

    /**
     * Construct a builder initialized with state from specified {@link PathComputationClient}.
     *
     * @param base PathComputationClient from which the builder should be initialized
     */
    public PathComputationClientBuilder(final PathComputationClient base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._ipAddress = base.getIpAddress();
        this._reportedLsp = base.getReportedLsp();
        this._stateSync = base.getStateSync();
        this._statefulTlv = base.getStatefulTlv();
    }


    private static final class LazyEmpty {
        static final @NonNull PathComputationClient INSTANCE = new PathComputationClientBuilder().build();
    
        private LazyEmpty() {
            // Hidden on purpose
        }
    }
    
    /**
     * Get empty instance of PathComputationClient.
     *
     * @return An empty {@link PathComputationClient}
     */
    public static @NonNull PathComputationClient empty() {
        return LazyEmpty.INSTANCE;
    }

    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getIpAddress()}.
     *
     * @return current value
     */
    public IpAddressNoZone getIpAddress() {
        return _ipAddress;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getReportedLsp()}.
     *
     * @return current value
     */
    public Map<ReportedLspKey, ReportedLsp> getReportedLsp() {
        return _reportedLsp;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getStateSync()}.
     *
     * @return current value
     */
    public PccSyncState getStateSync() {
        return _stateSync;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link PathComputationClient#getStatefulTlv()}.
     *
     * @return current value
     */
    public StatefulTlv getStatefulTlv() {
        return _statefulTlv;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<PathComputationClient>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    /**
     * Set the property corresponding to {@link PathComputationClient#getIpAddress()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PathComputationClientBuilder setIpAddress(final IpAddressNoZone value) {
        this._ipAddress = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link PathComputationClient#getReportedLsp()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public PathComputationClientBuilder setReportedLsp(final Map<ReportedLspKey, ReportedLsp> values) {
        this._reportedLsp = values;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link PathComputationClient#getStateSync()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PathComputationClientBuilder setStateSync(final PccSyncState value) {
        this._stateSync = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link PathComputationClient#getStatefulTlv()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PathComputationClientBuilder setStatefulTlv(final StatefulTlv value) {
        this._statefulTlv = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public PathComputationClientBuilder addAugmentation(Augmentation<PathComputationClient> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public PathComputationClientBuilder removeAugmentation(Class<? extends Augmentation<PathComputationClient>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link PathComputationClient} instance.
     *
     * @return A new {@link PathComputationClient} instance.
     */
    public @NonNull PathComputationClient build() {
        return new PathComputationClientImpl(this);
    }

    private static final class PathComputationClientImpl
        extends AbstractAugmentable<PathComputationClient>
        implements PathComputationClient {
    
        private final IpAddressNoZone _ipAddress;
        private final Map<ReportedLspKey, ReportedLsp> _reportedLsp;
        private final PccSyncState _stateSync;
        private final StatefulTlv _statefulTlv;
    
        PathComputationClientImpl(final PathComputationClientBuilder base) {
            super(base.augmentation);
            this._ipAddress = base.getIpAddress();
            this._reportedLsp = CodeHelpers.emptyToNull(base.getReportedLsp());
            this._stateSync = base.getStateSync();
            this._statefulTlv = base.getStatefulTlv();
        }
    
        @Override
        public IpAddressNoZone getIpAddress() {
            return _ipAddress;
        }
        
        @Override
        public Map<ReportedLspKey, ReportedLsp> getReportedLsp() {
            return _reportedLsp;
        }
        
        @Override
        public PccSyncState getStateSync() {
            return _stateSync;
        }
        
        @Override
        public StatefulTlv getStatefulTlv() {
            return _statefulTlv;
        }
    
        
        
        
        @Override
        public StatefulTlv nonnullStatefulTlv() {
            return Objects.requireNonNullElse(getStatefulTlv(), org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.pcep.rev220730.pcep.client.attributes.path.computation.client.StatefulTlvBuilder.empty());
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = PathComputationClient.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return PathComputationClient.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return PathComputationClient.bindingToString(this);
        }
    }
}
